FhirDate class

Inheritance
Annotations
  • @immutable

Constructors

FhirDate(dynamic inValue)
factory
FhirDate.fromJson(String json)
factory
FhirDate.fromUnits({required int year, int? month, int? day, int? hour, int? minute, int? second, int? millisecond, int? microsecond, bool? isUtc})
factory
FhirDate.fromYaml(String yaml)
factory

Properties

day → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hour → int
no setterinherited
isUtc → bool
no setterinherited
isValid → bool
finalinherited
microsecond → int
no setterinherited
millisecond → int
no setterinherited
minute → int
no setterinherited
month → int
no setterinherited
parseError → Exception?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
no setterinherited
timeZoneOffset → num
no setterinherited
value → DateTime
finalinherited
valueDateTime → DateTime
no setterinherited
valueString → String
no setterinherited
weekday → int
no setterinherited
year → int
no setterinherited

Methods

compareTo(Object other) → int
Compares this object to another object.
inherited
durationFromObject(Object other) → Duration?
inherited
isAfter(Object other) → bool?
inherited
isAtSameMomentAs(Object other) → bool?
inherited
isBefore(Object other) → bool?
inherited
isEqual(Object other) → bool?
inherited
isSameOrAfter(Object other) → bool?
inherited
isSameOrBefore(Object other) → bool?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plus(Object other) → FhirDate
override
subtract(Object other) → FhirDate
override
toIso8601String({bool asUtc = false}) → String
override
toJson() → String
inherited
toString() → String
A string representation of this object.
inherited
toYaml() → String
inherited

Operators

operator +(Object other) → FhirDate
inherited
operator -(Object other) → FhirDate
inherited
operator <(Object other) → bool?
inherited
operator <=(Object other) → bool?
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(Object other) → bool?
inherited
operator >=(Object other) → bool?
inherited