FhirDecimal class

Inheritance

Constructors

FhirDecimal(dynamic inValue)
factory
FhirDecimal.fromJson(dynamic json)
factory
FhirDecimal.fromYaml(dynamic yaml)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isInt → bool
final
isValid → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double?
no setteroverride
valueNumber → num?
finalinherited
valueString → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
override
toString() → String
A string representation of this object.
inherited
toYaml() → dynamic
override

Operators

operator <(Object o) → bool
inherited
operator <=(Object o) → bool
inherited
operator ==(Object o) → bool
The equality operator.
inherited
operator >(Object o) → bool
inherited
operator >=(Object o) → bool
inherited