FhirNumber class abstract

Implemented types
Implementers

Constructors

FhirNumber(String valueString, num? valueNumber, bool isValid)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isValid → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → num?
no setter
valueNumber → num?
final
valueString → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
override
toYaml() → dynamic

Operators

operator <(Object o) → bool
operator <=(Object o) → bool
operator ==(Object o) → bool
The equality operator.
override
operator >(Object o) → bool
operator >=(Object o) → bool