FhirTime class

Implemented types

Constructors

FhirTime(dynamic inValue)
factory
FhirTime.fromJson(dynamic json)
factory
FhirTime.fromUnits({dynamic hour, dynamic minute, dynamic second, dynamic millisecond})
factory
FhirTime.fromYaml(dynamic yaml)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
hour → int?
no setter
isValid → bool
no setter
millisecond → int?
no setter
minute → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int?
no setter
value → String?
no setter

Methods

compareTo(FhirTime other) → int
Compares this object to another object.
override
isEqual(Object o) → bool?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plus({int hours = 0, int minutes = 0, int seconds = 0, int milliseconds = 0}) → FhirTime
subtract({int hours = 0, int minutes = 0, int seconds = 0, int milliseconds = 0}) → FhirTime
toJson() → String
toString() → String
A string representation of this object.
override
toYaml() → String

Operators

operator <(Object o) → bool?
operator <=(Object o) → bool?
operator ==(Object o) → bool
The equality operator.
override
operator >(Object o) → bool?
operator >=(Object o) → bool?